@@ -46,5 +46,5 @@ class telegram:
             self.log(*items, level=level)
             self.log(level=level)
         elif level != 'debug': # Don't print debug only messages
-            print(items)
+            print(*items)
             print()
\ No newline at end of file
